version 13
clear all
cap log close
log using anng_revision_main, replace
set more off
set linesize 255
set matsize 2000

if !fileexists("pupfile3.dta") do crpupfile3

use pupfile3, clear

merge m:1 orgnr using surveywork

g surveyresponse = _m==3
drop _merge

g ng8y  = 0
label var ng8y "# Lower grades 8th"
g ng9y  = (mix9==8) + (mix9==3)
label var ng9y "# Lower grades 9th"
g ng10y = 2 * (mix10==3) + (mix10==9)
label var ng10y "# Lower grades 10th"

g ng8o  = 2 * (mix8==3) + (mix8==9)
label var ng8o "# Higher grades 8th"
g ng9o  = (mix9==3) + (mix9==1)
label var ng9o "# Higher grades 9th"
g ng10o = 0
label var ng10o "# Higher grades 10th"

g ng8   = 1 + ng8y + ng8o
g ng9   = 1 + ng9y + ng9o
g ng10  = 1 + ng10y + ng10o

egen ngy = rmean(ng8y ng9y ng10y)
label var ngy "# Lower grades"

egen ngo = rmean(ng8o ng9o ng10o)
label var ngo "# Higher grades"

g ng = 1 + ngy + ngo
label var ng "# Grades"

foreach v of var ng8o ng9y ng9o ng10y {
	replace `v' = `v' / 3
}

replace pcs8 = pup8_8 + (pmix8==3) * (pup9_8 + pup10_8) + 0.5 * pup9_8 * (pmix8==2)

local eoptions0 "label cells(b(fmt(3) star) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01)"
local eoptions "label cells(b(fmt(3) star) se(par fmt(3))) stats(r2 N_clust N, fmt(%7.4f %7.0g %7.0g)) starlevels(* 0.10 ** 0.05 *** 0.01)"
local ewideoptions "cells("b(fmt(3) star) se(par fmt(3))") starlevels(* 0.10 ** 0.05 *** 0.01)"

g byte pmix83 = pmix8==3
label var pmix83  "3 in 8th grade"
g byte pmix89 = pmix8==9
label var pmix89  "2 in 8th grade"
g byte pmix92 = (pmix9==1) | (pmix9==8)
label var pmix92  "2 in 9th grade"
g byte pmix93 = pmix9==3
label var pmix93  "3 in 9th grade"
g byte pmix103 = pmix10==3
label var pmix103 "3 in 10th grade"
g byte pmix102 = pmix10==9
label var pmix102 "2 in 10th grade"

label var csls "Class size"
label var ssize "School size / 100"
label var age "Relative Age"
label var girl "Girl"
label var med1 "M - Compulsory"
label var med2 "M - High school"
label var med3 "M - College"
label var fed1 "F - Compulsory"
label var fed2 "F - High school"
label var fed3 "F - College"
label var cohabit "Parents cohabit"
label var th "Teacher hours per pupil"
label var comb "Combined school"

// define some locals with controls and instruments
ta year, g(Dy)
unab xvars: age girl med2 med3 fed2 fed3 cohabit Dy*
unab endvar1: ng
unab endvar2: ngy ngo
unab endvar3: ng8 ng9 ng10
unab endvar4: ng8o ng9o ng9y ng10y
unab runvar : ssize

unab zvars: pmix83 pmix89 pmix93 pmix92 pmix103 pmix102

fvrevar pmix8##pmix9##pmix10, stub(_zpmix)
unab zvars_full : _zpmix*

local method 2sls


// survey response
probit surveyresponse `xvars' `runvar' csls `endvar2' if ds, cluster(orgnr)
testparm `xvars'
testparm `runvar' csls `endvar2'
testparm `xvars' `runvar' csls `endvar2'


// TABLE 2 -- DESCRIPTIVE STATISTICS
// student level
est clear
qui reg stdEx age girl med? fed? cohabit 
estadd summ, mean sd
est sto all
qui reg stdEx age girl med? fed? cohabit if ds
estadd summ, mean sd
est sto small
qui reg stdEx age girl med? fed? cohabit if ds & (mix8 | mix9 | mix10)
estadd summ, mean sd
est sto mix
estout *, cells("mean(fmt(2)) sd(par fmt(2))") stats(N, fmt(%9.0g)) drop(_cons) label

// school level
bys orgnr year : g sobs = (_n==1)
est clear
qui reg stdEx comb ssize csls th if sobs
estadd summ, mean sd
est sto all
qui reg stdEx ssize csls th if sobs & ds
estadd summ, mean sd
est sto small
qui reg stdEx ssize csls th if sobs & ds & (mix8 | mix9 | mix10)
estadd summ, mean sd
est sto mix
estout *, cells("mean(fmt(2)) sd(par fmt(2))") drop(_cons) label
codebook orgnr if sobs
codebook orgnr if sobs & ds 
codebook orgnr if sobs & ds & (mix8 | mix9 | mix10)


reg ds age girl med? fed? cohabit ssize csls th
testparm age girl med? fed? cohabit
testparm ssize csls th

g xmix = ds & (mix8 | mix9 | mix10)
reg xmix age girl med? fed? cohabit ssize csls th if ds
testparm age girl med? fed? cohabit
testparm ssize csls th


// TABLE 3 -- MIXING SEQUENCES
g nmix = string(ng8) + string(ng9) + string(ng10)
ta nmix if ds & sobs 


/************/
/* ANALYSIS */
/************/
replace ssize = ssize / 100
keep if ds

reg ngy `zvars' pcs8 `xvars' `runvar' ``spec'' if ds & stdEx<., cluster(orgnr) robust
testparm `zvars'
reg ngy `zvars_full' pcs8 `xvars' `runvar' ``spec'' if ds & stdEx<., cluster(orgnr) robust
testparm `zvars_full'

// instrument support
g pseq = string(pmix8) + string(pmix9) + string(pmix10)
bys pseq (orgnr) : g nschools = (orgnr != orgnr[_n - 1])
preserve
foreach v of var pmix83 pmix89 pmix93 pmix92 pmix103 pmix102 {
	replace `v' = `v' * nschools
}
collapse (sum) pmix83 pmix89 pmix93 pmix92 pmix103 pmix102 nschools if stdEx<., by(pseq)
list pseq nschools pmix*, noo sep(0)
restore

tab pmix8 pmix9
tab pmix8 pmix10

// FS - main specification
estimates clear
qui foreach v of var `endvar1' `endvar2' csls {
	reg `v' `zvars' pcs8 `xvars' `runvar'  if ds & stdEx<., cluster(orgnr) robust
	testparm pcs8 `zvars'
	estadd scalar fsF = r(F)
	testparm `zvars'
	estadd scalar fsFpmix = r(F)
	testparm pcs8
	estadd scalar fsFpcs8 = r(F)
	testparm `xvars'
	estadd scalar xp = r(p)
	est sto `v'
}
estout *, stats(fsF fsFpmix fsFpcs8 xp, fmt(%9.3f)) `ewideoptions' 


// REVISION: Reduced form main specification
estimates clear
egen pmix0 = rsum(`zvars')
ta pmix0
replace pmix0 = pmix0==0
qui foreach v of var stdEx stdTG {
	reg `v' pmix0 `zvars' pcs8 `xvars' `runvar'  if ds, cluster(orgnr) robust nocons
	testparm pcs8 `zvars'
	estadd scalar fsF = r(F)
	testparm `zvars'
	estadd scalar fsFpmix = r(F)
	testparm pcs8
	estadd scalar fsFpcs8 = r(F)
	testparm `xvars'
	estadd scalar xp = r(p)
	est sto `v'
}
estout *, stats(fsF fsFpmix fsFpcs8 xp, fmt(%9.3f)) `ewideoptions' 

estimates clear
qui foreach v of var stdEx stdTG {
	reg `v' `zvars' pcs8 `xvars' `runvar'  if ds, cluster(orgnr) robust
	testparm pcs8 `zvars'
	estadd scalar fsF = r(F)
	testparm `zvars'
	estadd scalar fsFpmix = r(F)
	testparm pcs8
	estadd scalar fsFpcs8 = r(F)
	testparm `xvars'
	estadd scalar xp = r(p)
	est sto `v'
}
estout *, stats(fsF fsFpmix fsFpcs8 xp, fmt(%9.3f)) `ewideoptions' 

// REVISION: first-stage F-stats for different instrument sets
local ols
local fe i.orgnr

foreach spec in ols {
	foreach z in zvars zvars_full {
		foreach endvar in endvar1 endvar2 endvar4 {
			estimates clear
			qui foreach v of var ``endvar'' csls {
				reg `v' ``z'' pcs8 `xvars' `runvar' ``spec'' if ds & stdEx<., cluster(orgnr) robust
				testparm pcs8 ``z''
				estadd scalar fsF = r(F)
				testparm ``z''
				estadd scalar fsFpmix = r(F)
				testparm pcs8
				estadd scalar fsFpcs8 = r(F)
				testparm `xvars'
				estadd scalar xp = r(p)
				est sto `v'
			}
			estout *, stats(fsF fsFpmix fsFpcs8 xp, fmt(%9.1f %9.1f %9.1f %9.3f)) `eoptions0' drop(*) title("instruments: `z', specification: `spec'")
		}
	}
}

// AVERAGE EFFECTS
//foreach method in 2sls liml {

estimates clear
foreach outvar of var stdEx stdTG {
	//qui reg `outvar' `endvar1' if ds, cluster(orgnr) robust
	//est sto ols
	qui reg `outvar' `endvar1' `xvars' `runvar' csls if ds, cluster(orgnr) robust
	est sto Fols`outvar'
	// 2SLS
	//qui ivregress `method' `outvar' (`endvar1' = `zvars') `xvars' `runvar' if ds, cluster(orgnr) robust 
	//est sto Fiv0nocs
	qui ivregress `method' `outvar' (`endvar1' = `zvars') csls `xvars' `runvar' if ds, cluster(orgnr) robust 
	est sto Fiv0cs`outvar'
	qui ivregress `method' `outvar' (`endvar1' csls = `zvars' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust 
	est sto Fiv0csiv`outvar'
	//qui ivregress `method' `outvar' (`endvar1' csls = `zvars_full' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust 
	//est sto Fiv0csfull`outvar'
}
estout *, `eoptions' title("method = `method'")

// full instruments
estimates clear
foreach outvar of var stdEx stdTG {
	qui ivregress `method' `outvar' (`endvar1' csls = `zvars_full' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust 
	est sto Fiv0csfull`outvar'
}
estout *, `eoptions' title("method = `method'")

// LOW VS HIGH EFFECTS
estimates clear
foreach outvar of var stdEx stdTG {
	qui reg   `outvar' `endvar2' csls `xvars' `runvar' if ds, cluster(orgnr) robust
	est sto ols
	//qui xtreg `outvar' `endvar2' csls `xvars' `runvar' if ds, fe i(orgnr) robust
	//est sto ols_fe
	qui ivregress `method' `outvar' (`endvar2' csls = `zvars' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust
	est sto iv
	//qui ivregress `method' `outvar' (`endvar2' csls = `zvars' pcs8) `xvars' `runvar' i.orgnr if ds, cluster(orgnr) robust 
	//est sto iv_fe
	qui ivregress `method' `outvar' (`endvar2' csls = `zvars_full' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust
	est sto ivfull
	//qui ivregress `method' `outvar' (`endvar2' csls = `zvars_full' pcs8) `xvars' `runvar' i.orgnr  if ds, cluster(orgnr) robust
	//est sto ivfull_fe
	estout *, `eoptions'  title("Outcome = `outvar', method = `method'")  //drop(*orgnr*)
}


// BY GENDER
g ngy1 = girl * ngy
g ngo1 = girl * ngo

foreach z of var `zvars' {
	g girl_x_`z' = girl * `z'
	local gzvars `gzvars' `z' girl_x_`z'
}

foreach outvar of var stdEx stdTG {
	// 2SLS
	estimates clear
	qui ivregress 2sls `outvar' (`endvar2' csls = `zvars' pcs8) `xvars' `runvar' if ds & girl==1, cluster(orgnr) robust
	est sto `outvar'_girl
	qui ivregress 2sls `outvar' (`endvar2' csls = `zvars_full' pcs8) `xvars' `runvar' if ds & girl==1, cluster(orgnr) robust
	est sto `outvar'_girlfull
	qui ivregress 2sls `outvar' (`endvar2' csls = `zvars' pcs8) `xvars' `runvar' if ds & girl==0, cluster(orgnr) robust 
	est sto `outvar'_boy
	qui ivregress 2sls `outvar' (`endvar2' csls = `zvars_full' pcs8) `xvars' `runvar' if ds & girl==0, cluster(orgnr) robust 
	est sto `outvar'_boyfull
	estout *, stats(N_clust N p_diff, fmt(a3)) `eoptions0' title("Outcome = `outvar', by gender")
	qui ivregress 2sls `outvar' (ngy ngo ngy1 ngo1 csls = `gzvars' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust 
	test ngy1 ngo1
}


//} // end method loop


// REVISION: GRADE SPECIFIC LOW vs HIGH EFFECTS
foreach i of num 1 2 4 {
	estimates clear
	qui foreach outvar of var stdEx stdTG {
		reg   `outvar' `endvar`i'' csls `xvars' `runvar' if ds, cluster(orgnr) robust
		est sto ols`outvar'
		ivreg2 `outvar' (`endvar`i'' csls = `zvars' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust ffirst
		estadd scalar pk_pval = e(idp)
		est sto iv`outvar'
		//ivreg2 `outvar' (`endvar`i'' csls = `zvars_full' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust ffirst
		//estadd scalar pk_pval = e(idp)
		//est sto ivfull`outvar'
	}
	noi estout *, `eoptions0'  title("Outcome = `outvar'") keep(`endvar`i'') stats(pk_pval, fmt(%9.3f))
}


// LIML
foreach i of num 1 2 4 {
	estimates clear
	qui foreach outvar of var stdEx stdTG {
		reg   `outvar' `endvar`i'' csls `xvars' `runvar' if ds, cluster(orgnr) robust
		est sto ols`outvar'
		ivreg2 `outvar' (`endvar`i'' csls = `zvars' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust ffirst liml
		estadd scalar pk_pval = e(idp)
		est sto iv`outvar'
		//ivreg2 `outvar' (`endvar`i'' csls = `zvars_full' pcs8) `xvars' `runvar' if ds, cluster(orgnr) robust ffirst liml
		//estadd scalar pk_pval = e(idp)
		//est sto ivfull`outvar'
	}
	noi estout *, `eoptions0'  title("Outcome = `outvar'") keep(`endvar`i'') stats(pk_pval, fmt(%9.3f))
}

log close
exit
