version 13

use id year anc* pup* using enrollnc0, clear
merge 1:m id year using GSI97_04, keepusing(enhetsnr ansvar insttype a09b a10b a11b b01d b01e mno) keep(match)

g CODE_LOCAL = string(mno, "%04.0f")
bys CODE: g nschoolskom = _N

keep if ansvar=="K" & insttype =="G"  // municipal compulsory schools

rename b01d thoursls
label var thoursls "Number of teacher hours in LS (current)"

rename b01e thours
label var thours "Number of teacher hours PS + LS (current)"

rename a09b ngirls8
label var ngirls8  "Nr of girls in 8th grade (current)"

rename a10b ngirls9
label var ngirls9  "Nr of girls in 9th grade (current)"

rename a11b ngirls10
label var ngirls10 "Nr of girls in 10th grade (current)"

rename enhetsnr orgnr
label var orgnr "school's id number"

egen pupprim = rsum(pup1-pup7)
egen pupls   = rsum(pup8-pup10)
gen comb = pupprim>0 & pupls>0

// mixing in primary school
gen amix7 = "7" if anc7>0 & anc6>0
replace amix7 = "76" if anc7==1 & anc6==0 & anc5>0
replace amix7 = "765" if anc7==1 & anc6==0 & anc5==0 & anc4>0
replace amix7 = "7654" if anc7==1 & anc6==0 & anc5==0 & anc4==0 & anc3>0
replace amix7 = "76543" if anc7==1 & anc6==0 & anc5==0 & anc4==0 & anc3==0 & anc2>0
replace amix7 = "765432" if anc7==1 & anc6==0 & anc5==0 & anc4==0 & anc3==0 & anc2==0

gen amix6 = "6" if anc7>0 & anc6>0 & anc5>0
replace amix6 = "76" if anc7==1 & anc6==0 & anc5>0
replace amix6 = "765" if anc7==1 & anc6==0 & anc5==0 & anc4>0
replace amix6 = "7654" if anc7==1 & anc6==0 & anc5==0 & anc4==0 & anc3>0
replace amix6 = "76543" if anc7==1 & anc6==0 & anc5==0 & anc4==0 & anc3==0 & anc2>0
replace amix6 = "765432" if anc7==1 & anc6==0 & anc5==0 & anc4==0 & anc3==0 & anc2==0
replace amix6 = "65" if anc7==1 & anc6==1 & anc5==0 & anc4>0
replace amix6 = "654" if anc7==1 & anc6==1 & anc5==0 & anc4==0 & anc3>0
replace amix6 = "6543" if anc7==1 & anc6==1 & anc5==0 & anc4==0 & anc3==0 & anc2>0
replace amix6 = "65432" if anc7==1 & anc6==1 & anc5==0 & anc4==0 & anc3==0 & anc2==0

egen psnclass = rsum(anc1-anc7)

// NOW lower secondary school
renpfix anc cnc
label var cnc10 "Nr of classes in 10th grade (current)"
label var cnc9  "Nr of classes in 9th grade (current)"
label var cnc8  "Nr of classes in 8th grade (current)"

renpfix pup cpup
label var cpup8  "Enrollment 8th grade (current)"
label var cpup9  "Enrollment 9th grade (current)"
label var cpup10 "Enrollment 10th grade (current)"

// in the test score file (cohort86_91.dta) year refers to year of test:
// so THERE year = 2001 is school year 2000/2001
// which means that HERE we add 1 to match the definition THERE
replace year = year + 1

// actual grade mixing
g amix = 0 if cnc8>=1 & cnc9>=1 & cnc10>=1
replace amix = 89  if cnc8==0 & cnc9==1 & cnc10>=1
replace amix = 910 if cnc8>=1 & cnc9==0 & cnc10==1
replace amix = 910 if cnc8>=1 & cnc9==1 & cnc10==0  // REVISION: added
replace amix = 8910 if (cnc8 + cnc9 + cnc10)==1
label var amix "Actual grade mixing (current)"

// predicted grade mixing
g cpup89 = cpup8 + cpup9
label var cpup89 "Nr of pupils in 8th and 9th grade (current)"
g cpup910 = cpup9 + cpup10
label var cpup910 "Nr of pupils in 9th and 10th grade (current)"
g cpup8910 = cpup8 + cpup9 + cpup10
label var cpup8910 "Nr of pupils in 8th + 9th and 10th grade (current)"
g pmix = 0 if (cpup89 >= 25 & cpup910 >= 25) & cpup8910 > 18
replace pmix = 8910 if cpup8910 <= 18
replace pmix = 89   if cpup8910 >  18 & (cpup89  <  cpup910 & cpup89  < 25)
replace pmix = 89   if cpup8910 >  18 & (cpup89  == cpup910 & cpup89  < 25) // REVISION: added
replace pmix = 910  if cpup8910 >  18 & (cpup910 <  cpup89  & cpup910 < 25)
label var pmix "Predicted grade mixing (current)"

forv grade = 8/10 {
        // actual class size
        g ccs`grade' = cpup`grade'/cnc`grade'
        replace ccs`grade' = (cpup8+cpup9+cpup10) if amix==8910
        replace ccs`grade' = (cpup8+cpup9) if amix==89 & (`grade'==8 | `grade'==9)
        replace ccs`grade' = (cpup9+cpup10) if amix==910 & (`grade'==9 | `grade'==10)
        label var ccs`grade' "Class size, grade `grade'"
        // predicted # classes
        g pcnc`grade' = int((cpup`grade' - 1) / 30) + 1
        // predicted class size
        g pccs`grade' = cpup`grade'/pcnc`grade'
        replace pccs`grade' = (cpup8+cpup9+cpup10) if pmix==8910
        replace pccs`grade' = (cpup8+cpup9) if pmix==89 & (`grade'==8 | `grade'==9)
        replace pccs`grade' = (cpup9+cpup10) if pmix==910 & (`grade'==9 | `grade'==10)
        label var pccs`grade' "Predicted class size, grade `grade'"
}

tsset orgnr year

forv j = 8/10 {
	local lag = 10 - `j'
	forv i = 8/10 {
		g pup`i'_`j' = l`lag'.cpup`i'
		label var pup`i'_`j' "# `i'th graders when in `j' grade"
		g ngirls`i'_`j' = l`lag'.ngirls`i'
		label var ngirls`i'_`j' "# `i'th grade girls when in `j' grade"
	}
	g thoursls_`j' = l`lag'.thoursls
	label var thoursls_`j' "# teacher hours LS when in `j' grade"
	g thours_`j' = l`lag'.thours
	label var thours_`j' "# teacher hours PS+LS when in `j' grade"
	g cs`j' = l`lag'.ccs`j'
	label var cs`j' "Class size when in `j'th grade"
	g pcs`j' = l`lag'.pccs`j'
	label var pcs`j' "Predicted class size when in `j'th grade"
}


//generate dummy variables for grade mixing
g Lamix  = l.amix
g L2amix = l2.amix
g Lpmix  = l.pmix
g L2pmix = l2.pmix

g mix8 = 0 + 9*(L2amix==89) + 3*(L2amix==8910) if L2amix<.
label var mix8 "Actual grade mixing when in 8th grade"

g mix9 = 0 + 1*(Lamix==910) + 3*(Lamix==8910) + 8*(Lamix==89) if Lamix<.
label var mix9 "Actual grade mixing when in 9th grade"

g mix10 = 0 + 9*(amix==910) + 3*(amix==8910) if amix<.
label var mix10 "Actual grade mixing when in 10th grade"

g seq = string(mix8) + string(mix9) + string(mix10)
tab seq
tab seq if year>2001

g pmix8  = 0 + 9*(L2pmix==89) + 3*(L2pmix==8910) if L2pmix<.
label var pmix8 "Predicted grade mixing when in 8th grade"

g pmix9  = 0 + 1*(Lpmix==910) + 3*(Lpmix==8910) + 8*(Lpmix==89) if Lpmix<.
label var pmix9 "Predicted grade mixing when in 9th grade"

g pmix10 = 0 + 9*(pmix==910)  + 3*(pmix==8910) if pmix<.
label var pmix10 "Predicted grade mixing when in 10th grade"

g pseq = string(pmix8) + string(pmix9) + string(pmix10)
tab pseq
tab pseq if year>2001

egen ssize = rsum(pup8_8 pup9_8 pup10_8)
egen csls  = rmean(cs8 cs9 cs10)
g th = thoursls_8 / ssize


// one predicted class when in 8th grade, and a school no smaller than 10
g byte dssample_city = pup8_8<=30 & l2.comb==1

// end of primary
foreach v of var amix6 amix7 psnclass cnc7 cnc6 {
	tempvar vlag
	bys orgnr (year) : g `vlag' = `v'[_n - 4] if year==(year[_n - 4] + 4)
	replace `v' = `vlag'
}

keep th thours*_* comb* amix orgnr year pup* mix* pmix?* seq cs* pcs* dssample* ngirls*_* ssize amix6 amix7 psnclass cnc7 cnc6 CODE_LOCAL nschoolskom
order orgnr year pup* ngirl* thour* mix* pmix?* seq cs* pcs*

compress
sort orgnr year


save mix3, replace
