version 13
clear all

if !fileexists("mix3.dta") do crmix3

use cohort86_91

rename kjonn girl
label var girl "Girl"

gen bdate = date(substr(fnr,1,6),"DM19Y")
gen age   = 1 - doy(bdate) / 365
label var age "Relative Age"

recode far (min/7=1) (7/10=1) (11/13=2) (14/max=3) (.=9999), gen(fed)
recode mor (min/7=1) (7/10=1) (11/13=2) (14/max=3) (.=9999), gen(med)
label def educ 1 "Lower secondary or less (0-10)" ///
               2 "Upper secondary (11-13)" ///
               3 "Higher Education (14+)"     ///
               9999 "Missing"
label val med educ
label val fed educ
label var med "Mother's education"
label var fed "Father's education"
forv i=1/3 {
	gen byte med`i' = (med==`i')
	gen byte fed`i' = (fed==`i')
}


g byte cohabit = (sambo==1)
label var cohabit "Parents cohabiting"

//standardize the grades and take average
rename aar year
levelsof year, local(years)
qui foreach y of local years {
	foreach v of var skr* stp* {
		sum `v' if year==`y'
		replace `v' = (`v' - r(mean)) / r(sd) if year==`y'
	}
}
egen stdExam = rmean(skr*)
label var stdExam "Average of standardized exam scores"

egen stdTG   = rmean(stp*)
label var stdTG "Average of standardized teacher grades"

keep year orgnr stdExam stdTG med* fed* iv girl cohabit age
merge m:m orgnr year using mix3, keep(match) nogen

compress
sort orgnr year
save pupfile3, replace
